Useful tools to work with Elastic stack in Python

# Description
    
This tool consists one module:

- `PeptideSearch`: this tool searches for peptides in a fasta file including proteins, it can find Exact Match or Marches with up to One Mismatch 

# Installation
 
## Normal installation

```bash
pip install PeptideSearch
```

## Development installation

```bash
git clone https://github.com/khaledianehdieh/PeptideSearch.git
```